OC.L10N.register(
    "core",
    {
    "Please select a file." : "Bitte wähle eine Datei aus.",
    "File is too big" : "Datei ist zu groß",
    "Invalid file provided" : "Ungültige Datei zur Verfügung gestellt",
    "No image or file provided" : "Es wurde weder ein Bild noch eine Datei zur Verfügung gestellt",
    "Unknown filetype" : "Unbekannter Dateityp",
    "Invalid image" : "Ungültiges Bild",
    "An error occurred. Please contact your admin." : "Ein Fehler ist aufgetreten. Bitte kontaktiere den Administrator.",
    "No temporary profile picture available, try again" : "Kein temporäres Profilbild verfügbar, bitte versuche es noch einmal",
    "No crop data provided" : "Keine Beschnittdaten zur Verfügung gestellt",
    "No valid crop data provided" : "Keine gültigen Zuschnittdaten zur Verfügung gestellt",
    "Crop is not square" : "Zuschnitt ist nicht quadratisch",
    "Could not reset password because the token is invalid" : "Das Passwort konnte aufgrund eines ungültigen Tokens nicht zurückgesetzt werden",
    "Could not reset password because the token expired" : "Das Passwort konnte nicht zurückgesetzt werden, da der Token abgelaufen ist",
    "Could not reset password because the token does not match" : "Das Passwort konnte aufgrund eines nicht übereinstimmenden Tokens nicht zurückgesetzt werden",
    "%s password changed successfully" : "%s Passwort erfolgreich geändert",
    "%s password reset" : "%s-Passwort zurücksetzen",
    "Couldn't send reset email. Please contact your administrator." : "Die E-Mail zum Zurücksetzen konnte nicht versendet werden. Bitte kontaktiere Deinen Administrator.",
    "Download / View" : "Herunterladen / Ansehen",
    "Recipients can view or download contents." : "Empfänger können Inhalte sehen und herunterladen.",
    "Download / View / Upload" : "Herunterladen / Ansehen / Hochladen",
    "Recipients can view, download and upload contents." : "Empfänger können Inhalte sehen, herunterladen und hochladen.",
    "Download / View / Edit" : "Herunterladen / Ansehen / Bearbeiten",
    "Recipients can view, download, edit, delete and upload contents." : "Empfänger können Inhalte sehen, herunterladen, ändern, löschen und hochladen.",
    "Upload only" : "Nur Hochladen",
    "Receive files from multiple recipients without revealing the contents of the folder." : "Von mehreren Empfängern Dateien empfangen, ohne den Inhalt des Ordners preiszugeben.",
    "Preparing update" : "Update vorbereiten",
    "[%d / %d]: %s" : "[%d / %d]: %s",
    "Repair warning: " : "Reparaturwarnung:",
    "Repair error: " : "Reparaturfehler:",
    "Please use the command line updater because automatic updating is disabled in the config.php." : "Da automatische Updates in der config.php deaktivert sind, nutze bitte den Updater über die Kommandozeile.",
    "[%d / %d]: Checking table %s" : "[%d / %d]: Überprüfe Tabelle %s",
    "Turned on maintenance mode" : "Wartungsmodus eingeschaltet",
    "Turned off maintenance mode" : "Wartungsmodus ausgeschaltet",
    "Maintenance mode is kept active" : "Wartungsmodus bleibt aktiviert",
    "Updating database schema" : "Datenbank-Schema wird aktualisiert",
    "Updated database" : "Datenbank aktualisiert",
    "Checking whether the database schema can be updated (this can take a long time depending on the database size)" : "Prüfen, ob das Datenbankschema aktualisiert werden kann (dies kann je nach Datenbankgröße sehr lange dauern)",
    "Checked database schema update" : "Datenbankschema-Aktualisierung überprüft",
    "Checking updates of apps" : "Es wird nach Updates für die Apps gesucht",
    "Checking whether the database schema for %s can be updated (this can take a long time depending on the database size)" : "Prüfen, ob das Datenbankschema für %s aktualisiert werden kann (dies kann je nach Datenbankgröße sehr lange dauern)",
    "Checked database schema update for apps" : "Datenbankschema-Aktualisierung für Apps überprüft",
    "Updated \"%s\" to %s" : "„%s“ zu %s aktualisiert",
    "Set log level to debug" : "Log-Level auf \"debug\" gesetzt",
    "Reset log level" : "Ursprüngliches Log-Level wiederhergestellt",
    "Starting code integrity check" : "Code-Integrität wird überprüft",
    "Finished code integrity check" : "Code-Integritätsprüfung abgeschlossen",
    "%s (3rdparty)" : "%s (3rdparty)",
    "%s (incompatible)" : "%s (nicht kompatibel)",
    "Following apps have been disabled: %s" : "Die folgenden Apps wurden deaktiviert: %s",
    "Already up to date" : "Bereits aktuell",
    "Sunday" : "Sonntag",
    "Monday" : "Montag",
    "Tuesday" : "Dienstag",
    "Wednesday" : "Mittwoch",
    "Thursday" : "Donnerstag",
    "Friday" : "Freitag",
    "Saturday" : "Samstag",
    "Sun." : "So",
    "Mon." : "Mo",
    "Tue." : "Di",
    "Wed." : "Mi",
    "Thu." : "Do",
    "Fri." : "Fr",
    "Sat." : "Sa",
    "Su" : "So",
    "Mo" : "Mo",
    "Tu" : "Di",
    "We" : "Mi",
    "Th" : "Do",
    "Fr" : "Fr",
    "Sa" : "Sa",
    "January" : "Januar",
    "February" : "Februar",
    "March" : "März",
    "April" : "April",
    "May" : "Mai",
    "June" : "Juni",
    "July" : "Juli",
    "August" : "August",
    "September" : "September",
    "October" : "Oktober",
    "November" : "November",
    "December" : "Dezember",
    "Jan." : "Jan.",
    "Feb." : "Feb.",
    "Mar." : "Mär.",
    "Apr." : "Apr.",
    "May." : "Mai",
    "Jun." : "Jun.",
    "Jul." : "Jul.",
    "Aug." : "Aug.",
    "Sep." : "Sep.",
    "Oct." : "Okt.",
    "Nov." : "Nov.",
    "Dec." : "Dez.",
    "<a href=\"{docUrl}\">There were problems with the code integrity check. More information…</a>" : "<a href=\"{docUrl}\">Es gab Probleme mit der Code - Integritätsprüfung. Mehr Informationen…</a>",
    "Settings" : "Einstellungen",
    "Problem loading page, reloading in 5 seconds" : "Problem beim Laden der Seite, Seite wird in 5 Sekunden nochmals geladen",
    "Saving..." : "Speichern…",
    "Dismiss" : "Ausblenden",
    "seconds ago" : "Gerade eben",
    "You have enabled one or more ownCloud Enterprise apps but your installation does not have a valid license yet." : "Du hast eine oder mehrere ownCloud Enterprise-Anwendungen aktiviert, aber die Installation verfügt über keine gültige Lizenz.",
    "A grace period of 24 hours has started to allow you to get going right away. Once the grace period ends, all Enterprise apps will become disabled unless you supply a valid license key." : "Eine Demo von 24 Stunden ist gerade gestartet damit Du sofort loslegen kannst. Nach Ablauf dieser Frist werden alle Enterprise-Anwendungen deaktiviert, es sei denn, Du gibst einen gültigen Lizenzschlüssel an.",
    "To try ownCloud Enterprise, just start a 30-day demo and enter the provided license key below." : "Um ownCloud Enterprise auszuprobieren, starte einfach eine 30-Tage-Demo und gib den unten angegebenen Lizenzschlüssel ein.",
    "Upgrade to ownCloud Enterprise" : "Upgrade auf ownCloud Enterprise",
    "Remaining time: {rtime}" : "Verbleibende Zeit: {rtime}",
    "Get your demo key" : "Demo-Lizenzschlüssel anfordern",
    "Enter license key" : "Lizenzschlüssel eintragen",
    "Set new key" : "Neuen Lizenzschlüssel eingeben:",
    "The link to reset your password has been sent to your email. If you do not receive it within a reasonable amount of time, check your spam/junk folders.<br>If it is not there ask your local administrator." : "Der Link zum Rücksetzen Deines Passworts ist an Deine E-Mail-Adresse versandt worden. Solltest Du ihn innerhalb eines annehmbaren Zeitraums nicht empfangen, prüfe bitte Deine Spam-Ordner.<br>Wenn er sich nicht darin befindet, frage bitte bei Deinem lokalen Administrator nach.",
    "Your files are encrypted. If you haven't enabled the recovery key, there will be no way to get your data back after your password is reset.<br />If you are not sure what to do, please contact your administrator before you continue. <br />Do you really want to continue?" : "Deine Dateien sind verschlüsselt. Solltest Du den Wiederherstellungsschlüssel nicht aktiviert haben, gibt es keine Möglichkeit, Deine Daten zurückzuerhalten, nachdem Dein Passwort zurückgesetzt ist.<br />Falls Du Dir nicht sicher bist, was zu tun ist, kontaktiere bitte Deinen Administrator, bevor Du fortfährst.<br />Willst Du wirklich fortfahren?",
    "I know what I'm doing" : "Ich weiß, was ich mache",
    "Password can not be changed. Please contact your administrator." : "Passwort kann nicht geändert werden. Bitte kontaktiere Deinen Administrator.",
    "Passwords do not match" : "Passwörter stimmen nicht überein ",
    "Error adding {addItem}: {addItem} already exists" : "Fehler beim Hinzufügen von {addItem},  {addItem} existiert schon.",
    "No" : "Nein",
    "Yes" : "Ja",
    "Choose" : "Auswählen",
    "Error loading file picker template: {error}" : "Fehler beim Laden der Dateiauswahlvorlage: {error}",
    "Ok" : "OK",
    "Error loading message template: {error}" : "Fehler beim Laden der Nachrichtenvorlage: {error}",
    "read-only" : "Schreibgeschützt",
    "_{count} file conflict_::_{count} file conflicts_" : ["{count} Dateikonflikt","{count} Dateikonflikte"],
    "One file conflict" : "Ein Dateikonflikt",
    "New Files" : "Neue Dateien",
    "Already existing files" : "Bereits existierende Dateien",
    "Which files do you want to keep?" : "Welche Dateien möchtest Du behalten?",
    "If you select both versions, the copied file will have a number added to its name." : "Wenn Du beide Versionen auswählst, erhält die kopierte Datei eine Zahl am Ende des Dateinamens.",
    "Cancel" : "Abbrechen",
    "Continue" : "Fortsetzen",
    "(all selected)" : "(Alle ausgewählt)",
    "({count} selected)" : "({count} ausgewählt)",
    "Error loading file exists template" : "Fehler beim Laden der vorhanden Dateivorlage",
    "Very weak password" : "Sehr schwaches Passwort",
    "Weak password" : "Schwaches Passwort",
    "So-so password" : "Durchschnittliches Passwort",
    "Good password" : "Gutes Passwort",
    "Strong password" : "Starkes Passwort",
    "Your web server is not yet set up properly to allow file synchronization because the WebDAV interface seems to be broken." : "Dein Webserver ist noch nicht hinreichend für Datei-Synchronisation konfiguriert, weil die WebDAV-Schnittstelle vermutlich defekt ist.",
    "Your web server is not set up properly to resolve \"{url}\". Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "Dein Web-Server ist nicht richtig eingerichtet um die folgende URL richtig aufzulösen \"{url}\". Weitere Informationen findest du in unserer <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">Dokumentation</a>.",
    "This server has no working Internet connection. This means that some of the features like mounting external storage, notifications about updates or installation of third-party apps will not work. Accessing files remotely and sending of notification emails might not work, either. We suggest to enable Internet connection for this server if you want to have all features." : "Dieser Server hat keine funktionierende Internetverbindung. Dies bedeutet, dass einige Funktionen wie das Einhängen externen Speicherplatzes, Update-Benachrichtigungen oder die Installation von Drittanbieter-Apps nicht funktionieren werden. Der Fernzugriff auf Dateien und der Versand von E-Mail-Benachrichtigungen kann ebenfalls nicht funktionieren. Es wird empfohlen, die Internetverbindung dieses Servers zu aktivieren, wenn Du alle Funktionen nutzen möchtest.",
    "No memory cache has been configured. To enhance your performance please configure a memcache if available. Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "Es wurde kein PHP Memory Cache konfiguriert. Konfiguriere zur Erhöhung der Leistungsfähigkeit, soweit verfügbar, einen Memory Cache. Weitere Informationen finden Sie in unserer <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">Dokumentation</a>.",
    "/dev/urandom is not readable by PHP which is highly discouraged for security reasons. Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "PHP hat keine Leserechte auf /dev/urandom wovon aus Sicherheitsgründen höchst abzuraten ist. Weitere Informationen sind in der <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">Dokumentation</a> zu finden.",
    "You are currently running PHP {version}. We encourage you to upgrade your PHP version to take advantage of <a target=\"_blank\" rel=\"noreferrer\" href=\"{phpLink}\">performance and security updates provided by the PHP Group</a> as soon as your distribution supports it." : "Du verwendest im Moment PHP {version}. Wir empfehlen ein Upgrade deiner PHP Version, um die <a target=\"_blank\" rel=\"noreferrer\" href=\"{phpLink}\">Geschwindigkeits- und Sicherheitsupdates zu nutzen, welche von der PHP Gruppe bereitgestellt werden</a>, sobald diese deine Distribution diese unterstützt.",
    "The reverse proxy headers configuration is incorrect, or you are accessing ownCloud from a trusted proxy. If you are not accessing ownCloud from a trusted proxy, this is a security issue and can allow an attacker to spoof their IP address as visible to ownCloud. Further information can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>." : "Die Header-Einstellungen des Reverse Proxy sind falsch, oder du versuchst, dich mit ownCloud von einem vertrauten Proxy aus zu verbinden. Solltest du ownCloud nicht von einem vertrauten Proxy aus benutzen wollen, dann stellt die momentane Situation ein Sicherheitsproblem da und erlaubt Hackern, eine für ownCloud sichtbare IP-Adresse zu nutzen. Weitere Informationen findest du in der <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">Dokumentation</a>.",
    "Memcached is configured as distributed cache, but the wrong PHP module \"memcache\" is installed. \\OC\\Memcache\\Memcached only supports \"memcached\" and not \"memcache\". See the <a target=\"_blank\" rel=\"noreferrer\" href=\"{wikiLink}\">memcached wiki about both modules</a>." : "Memcached ist als distributed cache konfiguriert aber das falsche PHP-Modul \"memcache\" ist installiert. \\OC\\Memcache\\Memcached unterstützt nur \"memcached\" jedoch nicht \"memcache\". Schau in der <a target=\"_blank\" rel=\"noreferrer\" href=\"{wikiLink}\">memcached wiki nach beiden Modulen</a>.",
    "Some files have not passed the integrity check. Further information on how to resolve this issue can be found in our <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">documentation</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">List of invalid files…</a> / <a href=\"{rescanEndpoint}\">Rescan…</a>)" : "Einige Dateien haben die Integritätsprüfung nicht bestanden. Weiterführende Information findest Du in unserer <a target=\"_blank\" rel=\"noreferrer\" href=\"{docLink}\">Dokumentation</a>. (<a href=\"{codeIntegrityDownloadEndpoint}\">Liste der ungültigen Dateien ...</a> / <a href=\"{rescanEndpoint}\">Erneut analysieren…</a>)",
    "You are running in DEBUG mode, this can cause unwanted side effects. Please remove the \"debug\" flag from \"config.php\"." : "Sie befinden sich im DEBUG Modus. Dies kann zu unerwarteten Effekten führen. Bitte entfernen Sie das \"debug\" Flag aus der \"config.php\".",
    "Error occurred while checking server setup" : "Fehler beim Überprüfen der Servereinrichtung",
    "Your data directory and your files are probably accessible from the Internet. The .htaccess file is not working. We strongly suggest that you configure your web server in a way that the data directory is no longer accessible or you move the data directory outside the web server document root." : "Dein Datenverzeichnis und Deine Dateien sind wahrscheinlich vom Internet aus erreichbar. Die .htaccess-Datei funktioniert nicht. Es wird dringend empfohlen, Deinen Webserver dahingehend zu konfigurieren, dass das Datenverzeichnis nicht mehr vom Internet aus erreichbar ist oder dass Du es aus dem Document-Root-Verzeichnis des Webservers herausverschiebst.",
    "The \"{header}\" HTTP header is not configured to equal to \"{expected}\". This is a potential security or privacy risk and we recommend adjusting this setting." : "Der „{header}“-HTTP-Header ist nicht so konfiguriert, dass er „{expected}“ entspricht. Dies ist ein potentielles Sicherheitsrisiko und es wird empfohlen, diese Einstellung zu ändern.",
    "The \"Strict-Transport-Security\" HTTP header is not configured to at least \"{seconds}\" seconds. For enhanced security we recommend enabling HSTS as described in our <a href=\"{docUrl}\" rel=\"noreferrer\">security tips</a>." : "Der \"Strict-Transport-Security\" HTTP-Header ist nicht auf mindestens \"{seconds}\" Sekunden eingestellt. Um die Sicherheit zu erhöhen, empfehlen wir das Aktivieren von HSTS, wie es in den <a href=\"{docUrl}\" rel=\"noreferrer\">Sicherheitshinweisen</a> erläutert ist.",
    "You are accessing this site via HTTP. We strongly suggest you configure your server to require using HTTPS instead as described in our <a href=\"{docUrl}\">security tips</a>." : "Du greifst auf diese Site über HTTP zu. Wir raten dringend dazu, Deinen Server so zu konfigurieren, dass er stattdessen nur HTTPS akzeptiert, wie es in unseren <a href=\"{docUrl}\">Sicherheitshinweisen</a> beschrieben ist.",
    "Shared" : "Geteilt",
    "Shared with {recipients}" : "Geteilt mit {recipients}",
    "Error" : "Fehler",
    "Error while sharing" : "Fehler beim Teilen",
    "Error while unsharing" : "Fehler beim Aufheben der Freigabe",
    "The public link will expire no later than {days} days after it is created" : "Der öffentliche Link wird spätestens {days} Tage nach seiner Erstellung ablaufen",
    "Expiration" : "Ablaufdatum",
    "Choose an expiration date" : "Wähle ein Ablaufdatum",
    "Expiration date is required" : "Ablaufdatum wird benötigt",
    "Delete {link}" : "{link} löschen",
    "Remove link" : "Link entfernen",
    "Link" : "Link",
    "Create public link" : "Öffentlichen Link erstellen",
    "Edit" : "Bearbeiten",
    "Remove" : "Entfernen",
    "Copy to clipboard" : "In Zwischenablage kopieren",
    "Social share" : "Soziales teilen",
    "There are currently no link shares, you can create one" : "Es gibt derzeit keine geteilten Links, du kannst einen erstellen",
    "Anyone with the link has access to the file/folder" : "Jeder mit dem Link hat Zugriff auf die Datei/Ordner",
    "Copied!" : "Kopiert!",
    "Not supported!" : "Nicht unterstützt!",
    "Press ⌘-C to copy." : "Zum Kopieren ⌘-C drücken.",
    "Press Ctrl-C to copy." : "Zum Kopieren Strg-C drücken.",
    "Choose a password" : "Ein Passwort wählen",
    "Password required" : "Passwort erforderlich",
    "Link name" : "Name des Links",
    "Name" : "Name",
    "Filename" : "Dateiname",
    "Password" : "Passwort",
    "Can not remove required password" : "Das Passwort kann nicht entfernt werden",
    "Edit link share: {name}" : "Geteilten Link bearbeiten: {name}",
    "Create link share: {name}" : "Geteilten Link erstellen: {name}",
    "Share" : "Teilen",
    "Save" : "Speichern",
    "Remove password" : "Passwort entfernen",
    "Share to Twitter. Opens in a new window." : "Über Twitter teilen. Wird in einem neuen Fenster geöffnet.",
    "Share to Facebook. Opens in a new window." : "Über Facebook teilen. Wird in einem neuen Fenster geöffnet.",
    "Share to Diaspora. Opens in a new window." : "Über Diaspora teilen. Wird in einem neuen Fenster geöffnet.",
    "Share to Google+. Opens in a new window." : "Über Google+ teilen. Wird in einem neuen Fenster geöffnet.",
    "Share via email. Opens your mail client." : "Über E-Mail teilen. Wird in einem neuen Fenster geöffnet.",
    "An error occurred while sending email" : "Beim Senden der E-Mail ist ein Fehler aufgetreten",
    "Email link to person" : "Link per E-Mail verschicken",
    "Send copy to self" : "Sende dir selbst ein Kopie",
    "Send link via email" : "Link als E-Mail verschicken",
    "Add personal message" : "Füge eine persönliche Nachricht an",
    "Sending" : "Senden",
    "E-Mail sent" : "E-Mail gesendet",
    "Shared with you and the group {group} by {owner}" : "{owner} hat dies mit Dir und der Gruppe {group} geteilt",
    "Shared with you by {owner}" : "{owner} hat dies mit Dir geteilt",
    "group" : "Gruppe",
    "federated" : "verbunden zu anderer Instanz",
    "notify by email" : "per E-Mail benachrichtigen",
    "Unshare" : "Freigabe aufheben",
    "can share" : "kann teilen",
    "can edit" : "kann bearbeiten",
    "create" : "erstellen",
    "change" : "ändern",
    "delete" : "löschen",
    "access control" : "Zugriffskontrolle",
    "Could not unshare" : "Freigabe konnte nicht entfernt werden",
    "Email notification was sent!" : "Mail-Benachrichtigung wurde versendet!",
    "Email notification not sent" : "Mail-Benachrichtigung wurde nicht versendet",
    "Share details could not be loaded for this item." : "Details der geteilten Freigabe konnten nicht geladen werden zu diesem Eintrag.",
    "No users or groups found for {search}" : "Kein Benutzer oder Gruppen gefunden für {search}",
    "No users found for {search}" : "Kein Benutzer gefunden für {search}",
    "_Please enter at least {chars} character for suggestions_::_Please enter at least {chars} characters for suggestions_" : ["Bitte mindestens {chars} Zeichen eingeben für Vorschläge","Bitte mindestens {chars} Zeichen eingeben für Vorschläge"],
    "An error occurred. Please try again" : "Es ist ein Fehler aufgetreten. Bitte versuche es noch einmal",
    "User" : "Benutzer",
    "Group" : "Gruppe",
    "Guest" : "Gast",
    "At {server}" : "Auf {server}",
    "Federated" : "Verbunden zu anderer Instanz",
    "User and Groups" : "Nutzer und Gruppen",
    "Public Links" : "Öffentliche Links",
    "Sharing is not allowed" : "Teilen nicht erlaubt",
    "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "Mit Benutzern anderer ownClouds unter Verwendung der Syntax benutzername@beispiel.com/owncloud teilen",
    "Share with users…" : "Mit Benutzern teilen…",
    "Share with users, groups or remote users…" : "Mit Benutzern, Gruppen oder entfernten Benutzern teilen…",
    "Share with users or groups…" : "Mit Benutzern oder Gruppen teilen…",
    "Share with users or remote users…" : "Mit Benutzern oder entfernten Benutzern teilen…",
    "Error removing share" : "Fehler beim Entfernen der Freigabe",
    "Unknown Share" : "Unbekannte Freigabe",
    "Non-existing tag #{tag}" : "Nicht vorhandener Tag #{tag}",
    "restricted" : "Eingeschränkt",
    "invisible" : "unsichtbar",
    "Static" : "Statisch",
    "({scope})" : "({scope})",
    "Delete" : "Löschen",
    "Rename" : "Umbenennen",
    "Collaborative tags" : "Gemeinschaftliche Tags",
    "The object type is not specified." : "Der Objekttyp ist nicht angegeben.",
    "Enter new" : "Neuen eingeben",
    "Add" : "Hinzufügen",
    "Edit tags" : "Schlagwörter bearbeiten",
    "Error loading dialog template: {error}" : "Fehler beim Laden der Dialogvorlage: {error}",
    "No tags selected for deletion." : "Es wurden keine Schlagwörter zum Löschen ausgewählt.",
    "unknown text" : "Unbekannter Text",
    "Hello world!" : "Hallo Welt!",
    "sunny" : "sonnig",
    "Hello {name}, the weather is {weather}" : "Hallo {name}, das Wetter ist {weather}",
    "Hello {name}" : "Hallo {name}",
    "new" : "neu",
    "_download %n file_::_download %n files_" : ["Lade %n Datei herunter","Lade %n Dateien herunter"],
    "The upgrade is in progress, leaving this page might interrupt the process in some environments." : "Das Update läuft gerade. Das Verlassen dieser Seite könnte den Update Prozess in einigen Umgebungen unterbrechen.",
    "Updating to {version}" : "Aktualisierung auf {version}",
    "An error occurred." : "Es ist ein Fehler aufgetreten.",
    "Please reload the page." : "Bitte lade die Seite neu.",
    "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Das Update war nicht erfolgreich. Für weitere Informationen <a href=\"{url}\"> schaue bitte in unser Forum </a> um das Problem zu lösen.",
    "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">ownCloud community</a>." : "Das Update ist fehlgeschlagen. Bitte melde dieses Problem an die <a href=\"https://github.com/owncloud/core/issues\" target=\"_blank\">ownCloud Community</a>.",
    "The update was successful. There were warnings." : "Das Update war erfolgreich. Warnungen wurden ausgegeben.",
    "The update was successful. Redirecting you to ownCloud now." : "Das Update war erfolgreich. Du wirst nun zu ownCloud weitergeleitet.",
    "Searching other places" : "Andere Orte durchsuchen",
    "No search results in other folders" : "Keine Suchergebnisse in anderen Ordnern",
    "_{count} search result in another folder_::_{count} search results in other folders_" : ["{count} Suchergebnis im anderen Ordner","{count} Suchergebnisse in anderen Ordnern"],
    "Personal" : "Persönlich",
    "Users" : "Benutzer",
    "Apps" : "Apps",
    "Admin" : "Administration",
    "Help" : "Hilfe",
    "Access forbidden" : "Zugriff verboten",
    "File not found" : "Datei nicht gefunden",
    "The specified document has not been found on the server." : "Das ausgewählte Dokument wurde auf dem Server nicht gefunden.",
    "You can click here to return to %s." : "Du kannst zur Rückkehr zu %s hier klicken.",
    "Hey there,\n\njust letting you know that %s shared %s with you.\nView it: %s\n\n" : "Hallo,\n\nhier nur kurz die Mitteilung, dass %s %s mit Dir geteilt hat.\nZum Anzeigen: %s\n\n",
    "The share will expire on %s." : "Die Freigabe wird am %s ablaufen.",
    "Personal note from the sender: \n %s." : "Persönliche Notiz vom Absender:\n%s.",
    "Cheers!" : "Noch einen schönen Tag!",
    "Internal Server Error" : "Interner Serverfehler",
    "The server encountered an internal error and was unable to complete your request." : "Der Server hat einen internen Fehler und konnte Ihre Anfrage nicht vervollständigen.",
    "Please contact the server administrator if this error reappears multiple times and include the technical details below in your report." : "Bitte wende dich an den Serveradministrator, sollte dieser Fehler mehrfach auftreten und füge deiner Anfrage die unten stehenden technischen Details bei.",
    "More details can be found in the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">server log</a>." : "Weitere Details können im <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">Serverprotokoll</a> gefunden werden.",
    "Technical details" : "Technische Details",
    "Remote Address: %s" : "Entfernte Adresse: %s",
    "Request ID: %s" : "Anforderungskennung: %s",
    "Type: %s" : "Typ: %s",
    "Code: %s" : "Code: %s",
    "Message: %s" : "Nachricht: %s",
    "File: %s" : "Datei: %s",
    "Line: %s" : "Zeile: %s",
    "Trace" : "Spur",
    "Imprint" : "Impressum",
    "Privacy Policy" : "Datenschutzerklärung",
    "Create an <strong>admin account</strong>" : "<strong>Administrator-Konto</strong> anlegen",
    "Username" : "Benutzername",
    "Storage & database" : "Speicher & Datenbank",
    "Data folder" : "Datenverzeichnis",
    "Configure the database" : "Datenbank einrichten",
    "Only %s is available." : "Es ist nur %s verfügbar.",
    "Install and activate additional PHP modules to choose other database types." : "Installiere und aktiviere zusätzliche PHP-Module, um andere Datenbank-Typen auswählen zu können.",
    "For more details check out the documentation." : "Schau für weitere Informationen in die Dokumentation.",
    "Database user" : "Datenbank-Benutzer",
    "Database password" : "Datenbank-Passwort",
    "Database name" : "Datenbank-Name",
    "Database tablespace" : "Datenbank-Tablespace",
    "Database host" : "Datenbank-Host",
    "Please specify the port number along with the host name (e.g., localhost: 5432)." : "Bitte die Portnummer zusammen mit dem Hostnamen angeben (z. B. localhost: 5432).",
    "Performance warning" : "Leistungswarnung",
    "SQLite will be used as database." : "SQLite wird als Datenbank benutzt.",
    "For larger installations we recommend to choose a different database backend." : "Bei größeren Installationen wird die Wahl eines anderen Datenbank-Backends empfohlen.",
    "Especially when using the desktop client for file syncing the use of SQLite is discouraged." : "Insbesondere bei Nutzung des Desktop Clients zur Dateisynchronisierung wird vom Einsatz von SQLite abgeraten.",
    "Finish setup" : "Installation abschließen",
    "Finishing …" : "Abschließen…",
    "Need help?" : "Hilfe nötig?",
    "See the documentation" : "Schau in die Dokumentation",
    "Hey there,<br><br>just letting you know that %s shared <strong>%s</strong> with you.<br><a href=\"%s\">View it!</a><br><br>" : "Hallo,<br><br>hier nur kurz die Mitteilung, dass %s <strong>%s</strong> mit Dir geteilt hat.<br><a href=\"%s\">Sieh es Dir an!</a><br><br>",
    "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Diese Anwendung benötigt zum ordnungsgemäßen Betrieb JavaScript. Bitte {linkstart}aktiviere JavaScript{linkend} und lade die Seite neu.",
    "Menu" : "Menü",
    "Log out" : "Abmelden",
    "Search" : "Suche",
    "Server side authentication failed!" : "Serverseitige Authentifizierung fehlgeschlagen!",
    "Please contact your administrator." : "Bitte kontaktiere Deinen Administrator.",
    "An internal error occurred." : "Es ist ein interner Fehler aufgetreten.",
    "Please try again or contact your administrator." : "Bitte versuche es noch einmal oder kontaktiere Deinen Administrator.",
    "Login" : "Anmelden",
    "Username or email" : "Benutzername oder E-Mail",
    "You took too long to log in, please try again now" : "Du hast zu lange zum Einloggen gebraucht, bitte versuche es erneut",
    "Wrong password. Reset it?" : "Falsches Passwort. Soll es zurückgesetzt werden?",
    "Wrong password." : "Falsches Passwort.",
    "You are trying to access a private link. Please log in first." : "Du versuchst auf einen privaten Link zuzugreifen. Bitte erst anmelden.",
    "Stay logged in" : "Angemeldet bleiben",
    "Alternative Logins" : "Alternative Logins",
    "Use the following link to reset your password: {link}" : "Benutze den folgenden Link, um Dein Passwort zurückzusetzen: {link}",
    "Password changed successfully" : "Passwort erfolgreich geändert",
    "New password" : "Neues Passwort",
    "New Password" : "Neues Passwort",
    "Confirm Password" : "Passwort bestätigen",
    "Reset password" : "Passwort zurücksetzen",
    "Personal note from the sender: <br> %s." : "Persönliche Notiz vom Absender: <br>%s.",
    "This ownCloud instance is currently in single user mode." : "Diese ownClound-Instanz befindet sich derzeit im Einzelbenutzermodus.",
    "This means only administrators can use the instance." : "Dies bedeutet, dass diese Instanz nur von Administratoren genutzt werden kann.",
    "Contact your system administrator if this message persists or appeared unexpectedly." : "Kontaktiere Deinen Systemadministrator, wenn diese Meldung dauerhaft oder unerwartet erscheint.",
    "Thank you for your patience." : "Vielen Dank für Deine Geduld.",
    "Two-step verification" : "Bestätigung in zwei Schritten",
    "Enhanced security has been enabled for your account. Please authenticate using a second factor." : "Die erweiterte Sicherheit wurde für dein Konto aktiviert. Bitte authentisiere dich mit einem zweiten Faktor. ",
    "Cancel login" : "Anmelden abbrechen",
    "Please authenticate using the selected factor." : "Bitte authentisiere dich mit dem ausgewählten zweiten Faktor. ",
    "An error occurred while verifying the token" : "Es ist ein Fehler bei der Verifizierung des Tokens aufgetreten",
    "You are accessing the server from an untrusted domain." : "Du greifst von einer nicht vertrauenswürdigen Domain auf den Server zu.",
    "Please contact your administrator. If you are an administrator of this instance, configure the \"trusted_domains\" setting in config/config.php. " : "Bitte kontaktiere deinen Administrator. Wenn du ein Administrator dieser Instanz bist, konfiguriere die \"trusted_domains\" Einstellung in config/config.php.",
    "An example configuration is provided in config/config.sample.php or at the <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation</a>." : "Eine Beispielkonfiguration wird unter config/config.sample.php in der <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">Dokumentation</a> bereitgestellt.",
    "App update required" : "Aktualisierung der Apps notwendig",
    "%s will be updated to version %s" : "%s wird auf Version %s aktuallisiert",
    "These apps will be updated:" : "Diese Apps werden aktuallisiert:",
    "The theme %s has been disabled." : "Das Theme %s wurde deaktiviert.",
    "Please make sure that the database, the config folder and the data folder have been backed up before proceeding." : "Bitte stelle vor dem Fortsetzen sicher, dass die Datenbank, der Konfigurationsordner und der Datenordner gesichert wurden.",
    "Start update" : "Aktualisierung starten",
    "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Zur Vermeidung von Zeitüberschreitungen bei größeren Installationen kannst Du stattdessen den folgenden Befehl in Deinem Installationsverzeichnis ausführen:",
    "Detailed logs" : "Detaillierte Fehlermeldungen",
    "Update needed" : "Update wird benötigt",
    "It looks like your instance may host many files and/or users. To ensure a smooth upgrade process, please use the command line updater (occ upgrade)." : "Es scheint, dass diese Installation viele Dateien und / oder Benutzer verwaltet. Um einen reibungslosen Upgrade-Prozess sicherzustellen, bitte die Kommandozeile benutzen (php occ upgrade).",
    "Automatic updating is disabled in config.php. To upgrade your instance, please use the command line updater (occ upgrade)." : "Automatische Aktualisierung ist in der Konfiguration deaktiviert. Zur Aktualisierung der Instanz bitte die Kommandozeile benutzen (php occ upgrade).",
    "For help, see the  <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">documentation</a>." : "Für weitere Hilfe bitte in die <a target=\"_blank\" rel=\"noreferrer\" href=\"%s\">Dokumentation</a> schauen.",
    "This %s instance is currently in maintenance mode, which may take a while." : "Diese %s-Instanz befindet sich gerade im Wartungsmodus, was eine Weile dauern kann.",
    "This page will refresh itself when the %s instance is available again." : "Diese Seite aktualisiert sich automatisch, wenn die %s-Instanz wieder verfügbar ist."
},
"nplurals=2; plural=(n != 1);");
